@@ -12,19 +12,19 @@ domain using Morlet wavelets and the debiased Squared Weighted Phase Lag Index
     physiological data in the presence of volume-conduction, noise and
     sample-size bias" NeuroImage, vol. 55, no. 4, pp. 1548-1565, Apr. 2011.
 """
-
 # Author: Martin Luessi <mluessi@nmr.mgh.harvard.edu>
 #
 # License: BSD (3-clause)
 
-print(__doc__)
-
 import numpy as np
+
 import mne
 from mne import io
 from mne.connectivity import spectral_connectivity, seed_target_indices
 from mne.datasets import sample
-from mne.viz import plot_topo_tfr
+from mne.time_frequency import AverageTFR
+
+print(__doc__)
 
 ###############################################################################
 # Set parameters
@@ -46,7 +46,8 @@ picks = mne.pick_types(raw.info, meg='grad', eeg=False, stim=False, eog=True,
 # Create epochs for left-visual condition
 event_id, tmin, tmax = 3, -0.2, 0.5
 epochs = mne.Epochs(raw, events, event_id, tmin, tmax, picks=picks,
-                    baseline=(None, 0), reject=dict(grad=4000e-13, eog=150e-6))
+                    baseline=(None, 0), reject=dict(grad=4000e-13, eog=150e-6),
+                    preload=True)
 
 # Use 'MEG 2343' as seed
 seed_ch = 'MEG 2343'
@@ -63,7 +64,8 @@ cwt_n_cycles = cwt_frequencies / 7.
 
 # Run the connectivity analysis using 2 parallel jobs
 sfreq = raw.info['sfreq']  # the sampling frequency
-con, freqs, times, _, _ = spectral_connectivity(epochs, indices=indices,
+con, freqs, times, _, _ = spectral_connectivity(
+    epochs, indices=indices,
     method='wpli2_debiased', mode='cwt_morlet', sfreq=sfreq,
     cwt_frequencies=cwt_frequencies, cwt_n_cycles=cwt_n_cycles, n_jobs=2)
 
@@ -71,9 +73,9 @@ con, freqs, times, _, _ = spectral_connectivity(epochs, indices=indices,
 con[np.where(indices[1] == seed)] = 1.0
 
 # Show topography of connectivity from seed
-import matplotlib.pyplot as plt
 title = 'WPLI2 - Visual - Seed %s' % seed_ch
 
 layout = mne.find_layout(epochs.info, 'meg')  # use full layout
-plot_topo_tfr(epochs, con, freqs, layout=layout, title=title)
-plt.show()
+
+tfr = AverageTFR(epochs.info, con, times, freqs, len(epochs))
+tfr.plot_topo(fig_facecolor='w', font_color='k', border='k')
