@@ -12,8 +12,6 @@ are used which produces strong connectvitiy in the right occipital sensors.
 #
 # License: BSD (3-clause)
 
-print(__doc__)
-
 import numpy as np
 from scipy import linalg
 
@@ -22,6 +20,8 @@ from mne import io
 from mne.connectivity import spectral_connectivity
 from mne.datasets import sample
 
+print(__doc__)
+
 ###############################################################################
 # Set parameters
 data_path = sample.data_path()
@@ -37,7 +37,7 @@ raw.info['bads'] += ['MEG 2443']
 
 # Pick MEG gradiometers
 picks = mne.pick_types(raw.info, meg='grad', eeg=False, stim=False, eog=True,
-                        exclude='bads')
+                       exclude='bads')
 
 # Create epochs for the visual condition
 event_id, tmin, tmax = 3, -0.2, 0.5
@@ -49,10 +49,9 @@ epochs = mne.Epochs(raw, events, event_id, tmin, tmax, picks=picks,
 fmin, fmax = 3., 9.
 sfreq = raw.info['sfreq']  # the sampling frequency
 tmin = 0.0  # exclude the baseline period
-con, freqs, times, n_epochs, n_tapers = spectral_connectivity(epochs,
-    method='pli', mode='multitaper', sfreq=sfreq,
-    fmin=fmin, fmax=fmax, faverage=True, tmin=tmin,
-    mt_adaptive=False, n_jobs=2)
+con, freqs, times, n_epochs, n_tapers = spectral_connectivity(
+    epochs, method='pli', mode='multitaper', sfreq=sfreq, fmin=fmin, fmax=fmax,
+    faverage=True, tmin=tmin, mt_adaptive=False, n_jobs=2)
 
 # the epochs contain an EOG channel, which we remove now
 ch_names = epochs.ch_names
@@ -64,10 +63,7 @@ con = con[idx][:, idx]
 con = con[:, :, 0]
 
 # Now, visualize the connectivity in 3D
-try:
-    from enthought.mayavi import mlab
-except:
-    from mayavi import mlab
+from mayavi import mlab  # noqa
 
 mlab.figure(size=(600, 600), bgcolor=(0.5, 0.5, 0.5))
 
@@ -76,7 +72,7 @@ sens_loc = [raw.info['chs'][picks[i]]['loc'][:3] for i in idx]
 sens_loc = np.array(sens_loc)
 
 pts = mlab.points3d(sens_loc[:, 0], sens_loc[:, 1], sens_loc[:, 2],
-                    color=(0, 0, 1), opacity=0.5, scale_factor=0.01)
+                    color=(1, 1, 1), opacity=1, scale_factor=0.005)
 
 # Get the strongest connections
 n_con = 20  # show up to 20 connections
@@ -100,8 +96,11 @@ vmin = np.min(con_val)
 for val, nodes in zip(con_val, con_nodes):
     x1, y1, z1 = sens_loc[nodes[0]]
     x2, y2, z2 = sens_loc[nodes[1]]
-    mlab.plot3d([x1, x2], [y1, y2], [z1, z2], [val, val],
-                vmin=vmin, vmax=vmax, tube_radius=0.002)
+    points = mlab.plot3d([x1, x2], [y1, y2], [z1, z2], [val, val],
+                         vmin=vmin, vmax=vmax, tube_radius=0.001,
+                         colormap='RdBu')
+    points.module_manager.scalar_lut_manager.reverse_lut = True
+
 
 mlab.scalarbar(title='Phase Lag Index (PLI)', nb_labels=4)
 
