@@ -11,13 +11,10 @@ The original reference for DICS is:
 Gross et al. Dynamic imaging of coherent sources: Studying neural interactions
 in the human brain. PNAS (2001) vol. 98 (2) pp. 694-699
 """
-
 # Author: Roman Goj <roman.goj@gmail.com>
 #
 # License: BSD (3-clause)
 
-print(__doc__)
-
 import mne
 
 import matplotlib.pyplot as plt
@@ -28,6 +25,8 @@ from mne.datasets import sample
 from mne.time_frequency import compute_epochs_csd
 from mne.beamformer import dics
 
+print(__doc__)
+
 data_path = sample.data_path()
 raw_fname = data_path + '/MEG/sample/sample_audvis_raw.fif'
 event_fname = data_path + '/MEG/sample/sample_audvis_raw-eve.fif'
@@ -78,12 +77,10 @@ plt.ylabel('DICS value')
 plt.title('DICS time course of the 30 largest sources.')
 plt.show()
 
-# Plot brain in 3D with PySurfer if available. Note that the subject name
-# is already known by the SourceEstimate stc object.
-brain = stc.plot(surface='inflated', hemi='rh', subjects_dir=subjects_dir)
+# Plot brain in 3D with PySurfer if available
+brain = stc.plot(hemi='rh', subjects_dir=subjects_dir)
 brain.set_data_time_index(180)
-brain.scale_data_colormap(fmin=4, fmid=6, fmax=8, transparent=True)
 brain.show_view('lateral')
 
 # Uncomment to save image
-#brain.save_image('DICS_map.png')
+# brain.save_image('DICS_map.png')
