@@ -10,12 +10,12 @@ The plot them to get an idea of the paradigm.
 #
 # License: BSD (3-clause)
 
-print(__doc__)
-
 import mne
 from mne.datasets import sample
 from mne.io import Raw
 
+print(__doc__)
+
 data_path = sample.data_path()
 fname = data_path + '/MEG/sample/sample_audvis_raw.fif'
 
@@ -25,7 +25,7 @@ raw = Raw(fname)
 events = mne.find_events(raw, stim_channel='STI 014')
 
 # Writing events
-mne.write_events('events.fif', events)
+mne.write_events('sample_audvis_raw-eve.fif', events)
 
 for ind, before, after in events[:5]:
     print("At sample %d stim channel went from %d to %d"
