@@ -11,7 +11,6 @@ Note: The MNE Real-time server (mne_rt_server), which is part of mne-cpp,
 has to be running on the same computer.
 """
 
-print(__doc__)
 
 # Authors: Martin Luessi <mluessi@nmr.mgh.harvard.edu>
 #          Mainak Jas <mainak@neuro.hut.fi>
@@ -19,10 +18,13 @@ print(__doc__)
 # License: BSD (3-clause)
 
 import matplotlib.pyplot as plt
+
 import mne
 from mne.datasets import sample
 from mne.realtime import RtEpochs, MockRtClient
 
+print(__doc__)
+
 # Fiff file to simulate the realtime client
 data_path = sample.data_path()
 raw_fname = data_path + '/MEG/sample/sample_audvis_filt-0-40_raw.fif'
@@ -49,9 +51,10 @@ rt_epochs.start()
 rt_client.send_data(rt_epochs, picks, tmin=0, tmax=150, buffer_size=1000)
 for ii, ev in enumerate(rt_epochs.iter_evoked()):
     print("Just got epoch %d" % (ii + 1))
-    if ii > 0:
-        ev += evoked
-    evoked = ev
-    plt.clf() # clear canvas
+    if ii == 0:
+        evoked = ev
+    else:
+        evoked += ev
+    plt.clf()  # clear canvas
     evoked.plot(axes=plt.gca())  # plot on current figure
     plt.pause(0.05)
