@@ -8,18 +8,19 @@ between conditions. Multiple comparison problem is addressed
 with cluster level permutation test.
 
 """
-
 # Authors: Alexandre Gramfort <alexandre.gramfort@telecom-paristech.fr>
 #
 # License: BSD (3-clause)
 
-print(__doc__)
+import matplotlib.pyplot as plt
 
 import mne
 from mne import io
 from mne.stats import permutation_cluster_test
 from mne.datasets import sample
 
+print(__doc__)
+
 ###############################################################################
 # Set parameters
 data_path = sample.data_path()
@@ -58,14 +59,12 @@ condition2 = condition2[:, 0, :]  # take only one channel to get a 2D array
 # Compute statistic
 threshold = 6.0
 T_obs, clusters, cluster_p_values, H0 = \
-                permutation_cluster_test([condition1, condition2],
-                            n_permutations=1000, threshold=threshold, tail=1,
-                            n_jobs=2)
+    permutation_cluster_test([condition1, condition2], n_permutations=1000,
+                             threshold=threshold, tail=1, n_jobs=2)
 
 ###############################################################################
 # Plot
 times = epochs1.times
-import matplotlib.pyplot as plt
 plt.close('all')
 plt.subplot(211)
 plt.title('Channel : ' + channel)
