@@ -15,15 +15,16 @@ latter also includes evoked (stimulus-locked) activity.
 #
 # License: BSD (3-clause)
 
-print(__doc__)
-
 import numpy as np
+import matplotlib.pyplot as plt
 
 import mne
 from mne import io
 from mne.datasets import sample
 from mne.minimum_norm import read_inverse_operator, source_induced_power
 
+print(__doc__)
+
 ###############################################################################
 # Set parameters
 data_path = sample.data_path()
@@ -44,7 +45,7 @@ raw.info['bads'] += ['MEG 2443', 'EEG 053']  # bads + 2 more
 
 # Picks MEG channels
 picks = mne.pick_types(raw.info, meg=True, eeg=False, eog=True,
-                        stim=False, include=include, exclude='bads')
+                       stim=False, include=include, exclude='bads')
 reject = dict(grad=4000e-13, mag=4e-12, eog=150e-6)
 
 # Load epochs
@@ -61,16 +62,15 @@ n_cycles = frequencies / 3.  # different number of cycle per frequency
 # subtract the evoked response in order to exclude evoked activity
 epochs_induced = epochs.copy().subtract_evoked()
 
-import matplotlib.pyplot as plt
 plt.close('all')
 
 for ii, (this_epochs, title) in enumerate(zip([epochs, epochs_induced],
                                               ['evoked + induced',
                                                'induced only'])):
     # compute the source space power and phase lock
-    power, phase_lock = source_induced_power(this_epochs, inverse_operator,
-        frequencies, label, baseline=(-0.1, 0), baseline_mode='percent',
-        n_cycles=n_cycles, n_jobs=1)
+    power, phase_lock = source_induced_power(
+        this_epochs, inverse_operator, frequencies, label, baseline=(-0.1, 0),
+        baseline_mode='percent', n_cycles=n_cycles, n_jobs=1)
 
     power = np.mean(power, axis=0)  # average over sources
     phase_lock = np.mean(phase_lock, axis=0)  # average over sources
@@ -82,7 +82,7 @@ for ii, (this_epochs, title) in enumerate(zip([epochs, epochs_induced],
     plt.subplot(2, 2, 2 * ii + 1)
     plt.imshow(20 * power,
                extent=[times[0], times[-1], frequencies[0], frequencies[-1]],
-               aspect='auto', origin='lower', vmin=0., vmax=30.)
+               aspect='auto', origin='lower', vmin=0., vmax=30., cmap='RdBu_r')
     plt.xlabel('Time (s)')
     plt.ylabel('Frequency (Hz)')
     plt.title('Power (%s)' % title)
@@ -91,7 +91,8 @@ for ii, (this_epochs, title) in enumerate(zip([epochs, epochs_induced],
     plt.subplot(2, 2, 2 * ii + 2)
     plt.imshow(phase_lock,
                extent=[times[0], times[-1], frequencies[0], frequencies[-1]],
-               aspect='auto', origin='lower', vmin=0, vmax=0.7)
+               aspect='auto', origin='lower', vmin=0, vmax=0.7,
+               cmap='RdBu_r')
     plt.xlabel('Time (s)')
     plt.ylabel('Frequency (Hz)')
     plt.title('Phase-lock (%s)' % title)
