@@ -29,11 +29,13 @@ def rescale(data, times, baseline, mode, verbose=None, copy=True):
         and if b is None then b is set to the end of the interval.
         If baseline is equal ot (None, None) all the time
         interval is used. If None, no correction is applied.
-    mode : 'logratio' | 'ratio' | 'zscore' | 'mean' | 'percent'
+    mode : 'logratio' | 'ratio' | 'zscore' | 'mean' | 'percent' | 'zlogratio'
         Do baseline correction with ratio (power is divided by mean
         power during baseline) or zscore (power is divided by standard
         deviation of power during baseline after subtracting the mean,
         power = [power - mean(power_baseline)] / std(power_baseline)).
+        logratio is the same an mean but in log-scale, zlogratio is the
+        same as zscore but data is rendered in log-scale first.
     verbose : bool, str, int, or None
         If not None, override default verbose level (see mne.verbose).
     copy : bool
@@ -47,9 +49,10 @@ def rescale(data, times, baseline, mode, verbose=None, copy=True):
     if copy:
         data = data.copy()
 
-    valid_modes = ['logratio', 'ratio', 'zscore', 'mean', 'percent']
+    valid_modes = ('logratio', 'ratio', 'zscore', 'mean', 'percent',
+                   'zlogratio')
     if mode not in valid_modes:
-        raise Exception('mode should be any of : %s' % valid_modes)
+        raise Exception('mode should be any of : %s' % (valid_modes, ))
 
     if baseline is not None:
         logger.info("Applying baseline correction ... (mode: %s)" % mode)
@@ -82,6 +85,11 @@ def rescale(data, times, baseline, mode, verbose=None, copy=True):
         elif mode == 'percent':
             data -= mean
             data /= mean
+        elif mode == 'zlogratio':
+            data /= mean
+            data = np.log10(data)
+            std = np.std(data[..., imin:imax], axis=-1)[..., None]
+            data /= std
 
     else:
         logger.info("No baseline correction applied...")
