@@ -11,14 +11,17 @@
 
 import os
 import os.path as op
+import warnings
 
 import numpy as np
 
 from ..viz import plot_montage
 from .channels import _contains_ch_type
 from ..transforms import (_sphere_to_cartesian, apply_trans,
-                          get_ras_to_neuromag_trans)
+                          get_ras_to_neuromag_trans, _topo_to_sphere)
 from ..io.meas_info import _make_dig_points, _read_dig_points
+from ..io.pick import pick_types
+from ..io.constants import FIFF
 from ..externals.six import string_types
 from ..externals.six.moves import map
 
@@ -51,8 +54,8 @@ class Montage(object):
         self.selection = selection
 
     def __repr__(self):
-        s = '<Montage | %s - %d Channels: %s ...>'
-        s %= self.kind, len(self.ch_names), ', '.join(self.ch_names[:3])
+        s = ('<Montage | %s - %d channels: %s ...>'
+             % (self.kind, len(self.ch_names), ', '.join(self.ch_names[:3])))
         return s
 
     def plot(self, scale_factor=1.5, show_names=False):
@@ -127,7 +130,7 @@ def read_montage(kind, ch_names=None, path=None, unit='m', transform=False):
     kind : str
         The name of the montage file (e.g. kind='easycap-M10' for
         'easycap-M10.txt'). Files with extensions '.elc', '.txt', '.csd',
-        '.elp', '.hpts' or '.sfp' are supported.
+        '.elp', '.hpts', '.sfp' or '.loc' ('.locs' and '.eloc') are supported.
     ch_names : list of str | None
         If not all electrodes defined in the montage are present in the EEG
         data, use this parameter to select subset of electrode positions to
@@ -153,13 +156,17 @@ def read_montage(kind, ch_names=None, path=None, unit='m', transform=False):
     -----
     Built-in montages are not scaled or transformed by default.
 
+    Montages can contain fiducial points in addition to electrode
+    locations, e.g. ``biosemi-64`` contains 67 total channels.
+
     .. versionadded:: 0.9.0
     """
 
     if path is None:
         path = op.join(op.dirname(__file__), 'data', 'montages')
     if not op.isabs(kind):
-        supported = ('.elc', '.txt', '.csd', '.sfp', '.elp', '.hpts')
+        supported = ('.elc', '.txt', '.csd', '.sfp', '.elp', '.hpts', '.loc',
+                     '.locs', '.eloc')
         montages = [op.splitext(f) for f in os.listdir(path)]
         montages = [m for m in montages if m[1] in supported and kind == m[0]]
         if len(montages) != 1:
@@ -254,6 +261,20 @@ def read_montage(kind, ch_names=None, path=None, unit='m', transform=False):
         data = np.loadtxt(fname, dtype=dtype)
         pos = np.vstack((data['x'], data['y'], data['z'])).T
         ch_names_ = data['name'].astype(np.str)
+    elif ext in ('.loc', '.locs', '.eloc'):
+        ch_names_ = np.loadtxt(fname, dtype='S4', usecols=[3]).tolist()
+        dtype = {'names': ('angle', 'radius'), 'formats': ('f4', 'f4')}
+        angle, radius = np.loadtxt(fname, dtype=dtype, usecols=[1, 2],
+                                   unpack=True)
+
+        sph_phi, sph_theta = _topo_to_sphere(angle, radius)
+
+        azimuth = sph_theta / 180.0 * np.pi
+        elevation = sph_phi / 180.0 * np.pi
+        r = np.ones((len(ch_names_), ))
+
+        x, y, z = _sphere_to_cartesian(azimuth, elevation, r)
+        pos = np.c_[-y, x, z]
     else:
         raise ValueError('Currently the "%s" template is not supported.' %
                          kind)
@@ -307,23 +328,22 @@ class DigMontage(object):
     Parameters
     ----------
     hsp : array, shape (n_points, 3)
-        The positions of the channels in 3d.
+        The positions of the headshape points in 3d.
+        These points are in the native digitizer space.
     hpi : array, shape (n_hpi, 3)
         The positions of the head-position indicator coils in 3d.
         These points are in the MEG device space.
     elp : array, shape (n_hpi, 3)
         The positions of the head-position indicator coils in 3d.
-        This is typically in the acquisition digitizer space.
+        This is typically in the native digitizer space.
     point_names : list, shape (n_elp)
         The names of the digitized points for hpi and elp.
     nasion : array, shape (1, 3)
-        The position of the nasion fidicual point in the RAS head space.
+        The position of the nasion fidicual point.
     lpa : array, shape (1, 3)
-        The position of the left periauricular fidicual point in
-        the RAS head space.
+        The position of the left periauricular fidicual point.
     rpa : array, shape (1, 3)
-        The position of the right periauricular fidicual point in
-        the RAS head space.
+        The position of the right periauricular fidicual point.
     dev_head_t : array, shape (4, 4)
         A Device-to-Head transformation matrix.
 
@@ -374,7 +394,7 @@ class DigMontage(object):
 
 def read_dig_montage(hsp=None, hpi=None, elp=None, point_names=None,
                      unit='mm', transform=True, dev_head_t=False):
-    """Read montage from a file
+    """Read digitization data from a file and generate a DigMontage
 
     Parameters
     ----------
@@ -382,17 +402,19 @@ def read_dig_montage(hsp=None, hpi=None, elp=None, point_names=None,
         If str, this corresponds to the filename of the headshape points.
         This is typically used with the Polhemus FastSCAN system.
         If numpy.array, this corresponds to an array of positions of the
-        channels in 3d.
+        headshape points in 3d. These points are in the native
+        digitizer space.
     hpi : None | str | array, shape (n_hpi, 3)
-        If str, this corresponds to the filename of hpi points. If numpy.array,
-        this corresponds to an array hpi points. These points are in
-        device space.
+        If str, this corresponds to the filename of Head Position Indicator
+        (HPI) points. If numpy.array, this corresponds to an array
+        of HPI points. These points are in device space.
     elp : None | str | array, shape (n_fids + n_hpi, 3)
-        If str, this corresponds to the filename of hpi points.
-        This is typically used with the Polhemus FastSCAN system.
-        If numpy.array, this corresponds to an array hpi points. These points
-        are in head space. Fiducials should be listed first, then the points
-        corresponding to the hpi.
+        If str, this corresponds to the filename of electrode position
+        points. This is typically used with the Polhemus FastSCAN system.
+        Fiducials should be listed first: nasion, left periauricular point,
+        right periauricular point, then the points corresponding to the HPI.
+        These points are in the native digitizer space.
+        If numpy.array, this corresponds to an array of fids + HPI points.
     point_names : None | list
         If list, this corresponds to a list of point names. This must be
         specified if elp is defined.
@@ -468,6 +490,13 @@ def read_dig_montage(hsp=None, hpi=None, elp=None, point_names=None,
         nasion = elp[names_lower.index('nasion')]
         lpa = elp[names_lower.index('lpa')]
         rpa = elp[names_lower.index('rpa')]
+
+        # remove fiducials from elp
+        mask = np.ones(len(names_lower), dtype=bool)
+        for fid in ['nasion', 'lpa', 'rpa']:
+            mask[names_lower.index(fid)] = False
+        elp = elp[mask]
+
         neuromag_trans = get_ras_to_neuromag_trans(nasion, lpa, rpa)
 
         fids = np.array([nasion, lpa, rpa])
@@ -478,7 +507,7 @@ def read_dig_montage(hsp=None, hpi=None, elp=None, point_names=None,
         fids = [None] * 3
     if dev_head_t:
         from ..coreg import fit_matched_points
-        trans = fit_matched_points(tgt_pts=elp[3:], src_pts=hpi, out='trans')
+        trans = fit_matched_points(tgt_pts=elp, src_pts=hpi, out='trans')
     else:
         trans = np.identity(4)
 
@@ -486,7 +515,7 @@ def read_dig_montage(hsp=None, hpi=None, elp=None, point_names=None,
                       trans)
 
 
-def _set_montage(info, montage):
+def _set_montage(info, montage, update_ch_names=False):
     """Apply montage to data.
 
     With a Montage, this function will replace the EEG channel names and
@@ -495,20 +524,38 @@ def _set_montage(info, montage):
     With a DigMontage, this function will replace the digitizer info with
     the values specified for the particular montage.
 
-    Note: This function will change the info variable in place.
+    Usually, a montage is expected to contain the positions of all EEG
+    electrodes and a warning is raised when this is not the case.
 
     Parameters
     ----------
     info : instance of Info
         The measurement info to update.
-    montage : instance of Montage
+    montage : instance of Montage | instance of DigMontage
         The montage to apply.
+    update_ch_names : bool
+        If True, overwrite the info channel names with the ones from montage.
+
+    Notes
+    -----
+    This function will change the info variable in place.
     """
     if isinstance(montage, Montage):
+        if update_ch_names:
+            info['ch_names'] = montage.ch_names
+            info['chs'] = list()
+            for ii, ch_name in enumerate(montage.ch_names):
+                ch_info = {'cal': 1., 'logno': ii + 1, 'scanno': ii + 1,
+                           'range': 1.0, 'unit_mul': 0, 'ch_name': ch_name,
+                           'unit': FIFF.FIFF_UNIT_V, 'kind': FIFF.FIFFV_EEG_CH,
+                           'coord_frame': FIFF.FIFFV_COORD_HEAD,
+                           'coil_type': FIFF.FIFFV_COIL_EEG}
+                info['chs'].append(ch_info)
+
         if not _contains_ch_type(info, 'eeg'):
             raise ValueError('No EEG channels found.')
 
-        sensors_found = False
+        sensors_found = []
         for pos, ch_name in zip(montage.pos, montage.ch_names):
             if ch_name not in info['ch_names']:
                 continue
@@ -516,12 +563,23 @@ def _set_montage(info, montage):
             ch_idx = info['ch_names'].index(ch_name)
             info['ch_names'][ch_idx] = ch_name
             info['chs'][ch_idx]['loc'] = np.r_[pos, [0.] * 9]
-            sensors_found = True
+            sensors_found.append(ch_idx)
 
-        if not sensors_found:
+        if len(sensors_found) == 0:
             raise ValueError('None of the sensors defined in the montage were '
                              'found in the info structure. Check the channel '
                              'names.')
+
+        eeg_sensors = pick_types(info, meg=False, ref_meg=False, eeg=True,
+                                 exclude=[])
+        not_found = np.setdiff1d(eeg_sensors, sensors_found)
+        if len(not_found) > 0:
+            not_found_names = [info['ch_names'][ch] for ch in not_found]
+            warnings.warn('The following EEG sensors did not have a position '
+                          'specified in the selected montage: ' +
+                          str(not_found_names) + '. Their position has been '
+                          'left untouched.')
+
     elif isinstance(montage, DigMontage):
         dig = _make_dig_points(nasion=montage.nasion, lpa=montage.lpa,
                                rpa=montage.rpa, hpi=montage.hpi,
