@@ -3,7 +3,9 @@
 
 You can do for example:
 
-$ mne compute_proj_ecg -i sample_audvis_raw.fif -c "MEG 1531" --l-freq 1 --h-freq 100 --rej-grad 3000 --rej-mag 4000 --rej-eeg 100
+$ mne compute_proj_ecg -i sample_audvis_raw.fif -c "MEG 1531" \
+                       --l-freq 1 --h-freq 100 \
+                       --rej-grad 3000 --rej-mag 4000 --rej-eeg 100
 """
 from __future__ import print_function
 
@@ -16,8 +18,7 @@ import sys
 import mne
 
 
-if __name__ == '__main__':
-
+def run():
     from mne.commands.utils import get_optparser
 
     parser = get_optparser(__file__)
@@ -155,7 +156,8 @@ if __name__ == '__main__':
             raise ValueError('qrsthr must be "auto" or a float')
 
     if bad_fname is not None:
-        bads = [w.rstrip().split()[0] for w in open(bad_fname).readlines()]
+        with open(bad_fname, 'r') as fid:
+            bads = [w.rstrip() for w in fid.readlines()]
         print('Bad channels read : %s' % bads)
     else:
         bads = []
@@ -168,9 +170,9 @@ if __name__ == '__main__':
     ecg_event_fname = prefix + '_ecg-eve.fif'
 
     if average:
-        ecg_proj_fname = prefix + '_ecg_avg_proj.fif'
+        ecg_proj_fname = prefix + '_ecg_avg-proj.fif'
     else:
-        ecg_proj_fname = prefix + '_ecg_proj.fif'
+        ecg_proj_fname = prefix + '_ecg-proj.fif'
 
     raw = mne.io.Raw(raw_in, preload=preload)
 
@@ -205,3 +207,7 @@ if __name__ == '__main__':
 
     print("Writing ECG events in %s" % ecg_event_fname)
     mne.write_events(ecg_event_fname, events)
+
+is_main = (__name__ == '__main__')
+if is_main:
+    run()
