@@ -1,5 +1,3 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*- 
-#ex: set sts=4 ts=4 sw=4 noet:
 """Some utility functions for commands (e.g. for cmdline handling)
 """
 
@@ -7,20 +5,28 @@
 #
 # License: BSD (3-clause)
 
-import imp, os, re
+import imp
+import os
+import re
 from optparse import OptionParser
 
 import mne
 
-def get_optparser(cmdpath):
-    """Create OptionParser with cmdsource specific settings (e.g. prog value)
+
+def get_optparser(cmdpath, usage=None):
+    """Create OptionParser with cmd source specific settings (e.g. prog value)
     """
     command = os.path.basename(cmdpath)
     if re.match('mne_(.*).py', command):
         command = command[4:-3]
+    elif re.match('mne_(.*).pyc', command):
+        command = command[4:-4]
 
     # Fetch description
-    mod = imp.load_source('__temp', cmdpath)
+    if cmdpath.endswith('.pyc'):
+        mod = imp.load_compiled('__temp', cmdpath)
+    else:
+        mod = imp.load_source('__temp', cmdpath)
     if mod.__doc__:
         doc, description, epilog = mod.__doc__, None, None
 
@@ -34,6 +40,6 @@ def get_optparser(cmdpath):
     parser = OptionParser(prog="mne %s" % command,
                           version=mne.__version__,
                           description=description,
-                          epilog=epilog)
+                          epilog=epilog, usage=usage)
 
     return parser
