@@ -4,5 +4,8 @@
 from . import sample
 from . import megsim
 from . import spm_face
+from . import brainstorm
 from . import eegbci
 from . import somato
+from . import testing
+from . import _fake
