@@ -107,7 +107,7 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
                 raise ValueError(r"'proj' must be 'True' or 'False'")
 
             #   Read the measurement info
-            info, meas = read_meas_info(fid, tree)
+            info, meas = read_meas_info(fid, tree, clean_bads=True)
             info['filename'] = fname
 
             #   Locate the data of interest
@@ -135,9 +135,16 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
                                      'found datasets:\n  %s'
                                      % (condition, kind, t))
                 condition = found_cond[0]
+            elif condition is None:
+                if len(evoked_node) > 1:
+                    _, _, conditions = _get_entries(fid, evoked_node)
+                    raise TypeError("Evoked file has more than one "
+                                    "conditions, the condition parameters "
+                                    "must be specified from:\n%s" % conditions)
+                else:
+                    condition = 0
 
             if condition >= len(evoked_node) or condition < 0:
-                fid.close()
                 raise ValueError('Data set selector out of range')
 
             my_evoked = evoked_node[condition]
@@ -285,6 +292,7 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
 
     def __repr__(self):
         s = "comment : '%s'" % self.comment
+        s += ', kind : %s' % self.kind
         s += ", time : [%f, %f]" % (self.times[0], self.times[-1])
         s += ", n_epochs : %d" % self.nave
         s += ", n_channels x n_times : %s x %s" % self.data.shape
@@ -345,7 +353,8 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
 
     def plot(self, picks=None, exclude='bads', unit=True, show=True, ylim=None,
              xlim='tight', proj=False, hline=None, units=None, scalings=None,
-             titles=None, axes=None, gfp=False):
+             titles=None, axes=None, gfp=False, window_title=None,
+             spatial_colors=False):
         """Plot evoked data as butterfly plots
 
         Left click to a line shows the channel name. Selecting an area by
@@ -392,11 +401,20 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
         gfp : bool | 'only'
             Plot GFP in green if True or "only". If "only", then the individual
             channel traces will not be shown.
+        window_title : str | None
+            The title to put at the top of the figure window.
+        spatial_colors : bool
+            If True, the lines are color coded by mapping physical sensor
+            coordinates into color values. Spatially similar channels will have
+            similar colors. Bad channels will be dotted. If False, the good
+            channels are plotted black and bad channels red. Defaults to False.
         """
         return plot_evoked(self, picks=picks, exclude=exclude, unit=unit,
                            show=show, ylim=ylim, proj=proj, xlim=xlim,
                            hline=hline, units=units, scalings=scalings,
-                           titles=titles, axes=axes, gfp=gfp)
+                           titles=titles, axes=axes, gfp=gfp,
+                           window_title=window_title,
+                           spatial_colors=spatial_colors)
 
     def plot_image(self, picks=None, exclude='bads', unit=True, show=True,
                    clim=None, xlim='tight', proj=False, units=None,
@@ -710,7 +728,8 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
                                   rank=None, show=show)
 
     def as_type(self, ch_type='grad', mode='fast'):
-        """Compute virtual evoked using interpolated fields in mag/grad channels.
+        """Compute virtual evoked using interpolated fields in mag/grad
+        channels.
 
         .. Warning:: Using virtual evoked to compute inverse can yield
             unexpected results. The virtual channels have `'_virtual'` appended
@@ -772,12 +791,12 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
             Either 0 or 1, the order of the detrending. 0 is a constant
             (DC) detrend, 1 is a linear detrend.
         picks : array-like of int | None
-            If None only MEG and EEG channels are detrended.
+            If None only MEG, EEG and SEEG channels are detrended.
         """
         if picks is None:
             picks = pick_types(self.info, meg=True, eeg=True, ref_meg=False,
                                stim=False, eog=False, ecg=False, emg=False,
-                               exclude='bads')
+                               seeg=True, exclude='bads')
         self.data[picks] = detrend(self.data[picks], order, axis=-1)
 
     def copy(self):
@@ -817,14 +836,16 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
 
         Parameters
         ----------
-        ch_type : {'mag', 'grad', 'eeg', 'misc', None}
+        ch_type : {'mag', 'grad', 'eeg', 'seeg', 'misc', None}
             The channel type to use. Defaults to None. If more than one sensor
             Type is present in the data the channel type has to be explicitly
             set.
         tmin : float | None
             The minimum point in time to be considered for peak getting.
+            If None (default), the beginning of the data is used.
         tmax : float | None
             The maximum point in time to be considered for peak getting.
+            If None (default), the end of the data is used.
         mode : {'pos', 'neg', 'abs'}
             How to deal with the sign of the data. If 'pos' only positive
             values will be considered. If 'neg' only negative values will
@@ -841,9 +862,10 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
             The time point of the maximum response, either latency in seconds
             or index.
         """
-        supported = ('mag', 'grad', 'eeg', 'misc', 'None')
+        supported = ('mag', 'grad', 'eeg', 'seeg', 'misc', 'None')
 
-        data_picks = pick_types(self.info, meg=True, eeg=True, ref_meg=False)
+        data_picks = pick_types(self.info, meg=True, eeg=True, seeg=True,
+                                ref_meg=False)
         types_used = set([channel_type(self.info, idx) for idx in data_picks])
 
         if str(ch_type) not in supported:
@@ -861,7 +883,7 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
                                'must not be `None`, pass a sensor type '
                                'value instead')
 
-        meg, eeg, misc, picks = False, False, False, None
+        meg, eeg, misc, seeg, picks = False, False, False, False, None
 
         if ch_type == 'mag':
             meg = ch_type
@@ -871,16 +893,22 @@ class Evoked(ProjMixin, ContainsMixin, UpdateChannelsMixin,
             eeg = True
         elif ch_type == 'misc':
             misc = True
+        elif ch_type == 'seeg':
+            seeg = True
 
         if ch_type is not None:
             picks = pick_types(self.info, meg=meg, eeg=eeg, misc=misc,
-                               ref_meg=False)
+                               seeg=seeg, ref_meg=False)
 
-        data = self.data if picks is None else self.data[picks]
+        data = self.data
+        ch_names = self.ch_names
+        if picks is not None:
+            data = data[picks]
+            ch_names = [ch_names[k] for k in picks]
         ch_idx, time_idx = _get_peak(data, self.times, tmin,
                                      tmax, mode)
 
-        return (self.ch_names[ch_idx],
+        return (ch_names[ch_idx],
                 time_idx if time_as_index else self.times[time_idx])
 
 
