@@ -59,7 +59,7 @@ def _check_coil_frame(coils, coord_frame, bem):
     return coils, coord_frame
 
 
-def _lin_field_coeff(surf, mult, rmags, cosmags, ws, n_int, n_jobs):
+def _lin_field_coeff(surf, mult, rmags, cosmags, ws, bins, n_jobs):
     """Parallel wrapper for _do_lin_field_coeff to compute linear coefficients.
 
     Parameters
@@ -73,10 +73,10 @@ def _lin_field_coeff(surf, mult, rmags, cosmags, ws, n_int, n_jobs):
         3D positions of MEG coil integration points (from coil['rmag'])
     cosmag : ndarray, shape (n_integration_pts, 3)
         Direction of the MEG coil integration points (from coil['cosmag'])
-    ws : ndarray, shape (n_sensor_pts,)
+    ws : ndarray, shape (n_integration_pts,)
         Weights for MEG coil integration points
-    n_int : ndarray, shape (n_MEG_sensors,)
-        Number of integration points for each MEG sensor
+    bins : ndarray, shape (n_integration_points,)
+        The sensor assignments for each rmag/cosmag/w.
     n_jobs : int
         Number of jobs to run in parallel
 
@@ -88,14 +88,14 @@ def _lin_field_coeff(surf, mult, rmags, cosmags, ws, n_int, n_jobs):
     """
     parallel, p_fun, _ = parallel_func(_do_lin_field_coeff, n_jobs)
     nas = np.array_split
-    coeffs = parallel(p_fun(surf['rr'], t, tn, ta, rmags, cosmags, ws, n_int)
+    coeffs = parallel(p_fun(surf['rr'], t, tn, ta, rmags, cosmags, ws, bins)
                       for t, tn, ta in zip(nas(surf['tris'], n_jobs),
                                            nas(surf['tri_nn'], n_jobs),
                                            nas(surf['tri_area'], n_jobs)))
     return mult * np.sum(coeffs, axis=0)
 
 
-def _do_lin_field_coeff(bem_rr, tris, tn, ta, rmags, cosmags, ws, n_int):
+def _do_lin_field_coeff(bem_rr, tris, tn, ta, rmags, cosmags, ws, bins):
     """Compute field coefficients (parallel-friendly).
 
     See section IV of Mosher et al., 1999 (specifically equation 35).
@@ -117,16 +117,15 @@ def _do_lin_field_coeff(bem_rr, tris, tn, ta, rmags, cosmags, ws, n_int):
         Direction of the MEG coil integration points (from coil['cosmag'])
     ws : ndarray, shape (n_sensor_pts,)
         Weights for MEG coil integration points
-    n_int : ndarray, shape (n_MEG_sensors,)
-        Number of integration points for each MEG sensor
+    bins : ndarray, shape (n_sensor_pts,)
+        The sensor assignments for each rmag/cosmag/w.
 
     Returns
     -------
     coeff : ndarray, shape (n_MEG_sensors, n_BEM_vertices)
         Linear coefficients with effect of each BEM vertex on each sensor (?)
     """
-    coeff = np.zeros((len(n_int), len(bem_rr)))
-    bins = np.repeat(np.arange(len(n_int)), n_int)
+    coeff = np.zeros((bins[-1] + 1, len(bem_rr)))
     for tri, tri_nn, tri_area in zip(tris, tn, ta):
         # Accumulate the coefficients for each triangle node and add to the
         # corresponding coefficient matrix
@@ -147,7 +146,7 @@ def _do_lin_field_coeff(bem_rr, tris, tn, ta, rmags, cosmags, ws, n_int):
             c = fast_cross_3d(diff, tri_nn[np.newaxis, :])
             x = tri_area * np.sum(c * cosmags, axis=1) / \
                 (3.0 * dl * np.sqrt(dl))
-            zz += [np.bincount(bins, weights=x * ws, minlength=len(n_int))]
+            zz += [np.bincount(bins, weights=x * ws, minlength=bins[-1] + 1)]
         coeff[:, tri] += np.array(zz).T
     return coeff
 
@@ -158,7 +157,13 @@ def _concatenate_coils(coils):
     cosmags = np.concatenate([coil['cosmag'] for coil in coils])
     ws = np.concatenate([coil['w'] for coil in coils])
     n_int = np.array([len(coil['rmag']) for coil in coils])
-    return rmags, cosmags, ws, n_int
+    if n_int[-1] == 0:
+        # We assume each sensor has at least one integration point,
+        # which should be a safe assumption. But let's check it here, since
+        # our code elsewhere relies on bins[-1] + 1 being the number of sensors
+        raise RuntimeError('not supported')
+    bins = np.repeat(np.arange(len(n_int)), n_int)
+    return rmags, cosmags, ws, bins
 
 
 def _bem_specify_coils(bem, coils, coord_frame, mults, n_jobs):
@@ -193,15 +198,15 @@ def _bem_specify_coils(bem, coils, coord_frame, mults, n_jobs):
     # potential approximation
 
     # Process each of the surfaces
-    rmags, cosmags, ws, n_int = _concatenate_coils(coils)
+    rmags, cosmags, ws, bins = _concatenate_coils(coils)
     lens = np.cumsum(np.r_[0, [len(s['rr']) for s in bem['surfs']]])
-    coeff = np.empty((len(n_int), lens[-1]))  # shape(n_coils, n_BEM_verts)
+    coeff = np.empty((bins[-1] + 1, lens[-1]))  # shape(n_coils, n_BEM_verts)
 
     # Compute coeffs for each surface, one at a time
     for o1, o2, surf, mult in zip(lens[:-1], lens[1:],
                                   bem['surfs'], bem['field_mult']):
         coeff[:, o1:o2] = _lin_field_coeff(surf, mult, rmags, cosmags, ws,
-                                           n_int, n_jobs)
+                                           bins, n_jobs)
     # put through the bem
     sol = np.dot(coeff, bem['solution'])
     sol *= mults
@@ -514,8 +519,7 @@ def _sphere_field(rrs, coils, sphere):
     The formulas have been manipulated for efficient computation
     by Matti Hamalainen, February 1990
     """
-    rmags, cosmags, ws, n_int = _concatenate_coils(coils)
-    bins = np.repeat(np.arange(len(n_int)), n_int)
+    rmags, cosmags, ws, bins = _concatenate_coils(coils)
 
     # Shift to the sphere model coordinates
     rrs = rrs - sphere['r0']
@@ -546,8 +550,7 @@ def _sphere_field(rrs, coils, sphere):
         v2 = fast_cross_3d(rr[np.newaxis, :], this_poss)
         xx = ((good * ws)[:, np.newaxis] *
               (v1 / F[:, np.newaxis] + v2 * g[:, np.newaxis]))
-        zz = np.array([np.bincount(bins, weights=x,
-                                   minlength=len(n_int)) for x in xx.T])
+        zz = np.array([np.bincount(bins, x, bins[-1] + 1) for x in xx.T])
         B[3 * ri:3 * ri + 3, :] = zz
     B *= _MAG_FACTOR
     return B
@@ -555,8 +558,7 @@ def _sphere_field(rrs, coils, sphere):
 
 def _eeg_spherepot_coil(rrs, coils, sphere):
     """Calculate the EEG in the sphere model."""
-    rmags, cosmags, ws, n_int = _concatenate_coils(coils)
-    bins = np.repeat(np.arange(len(n_int)), n_int)
+    rmags, cosmags, ws, bins = _concatenate_coils(coils)
 
     # Shift to the sphere model coordinates
     rrs = rrs - sphere['r0']
@@ -611,8 +613,7 @@ def _eeg_spherepot_coil(rrs, coils, sphere):
 
             # compute total result
             xx = vval_one * ws[:, np.newaxis]
-            zz = np.array([np.bincount(bins, weights=x,
-                                       minlength=len(n_int)) for x in xx.T])
+            zz = np.array([np.bincount(bins, x, bins[-1] + 1) for x in xx.T])
             B[3 * ri:3 * ri + 3, :] = zz
     # finishing by scaling by 1/(4*M_PI)
     B *= 0.25 / np.pi
@@ -624,7 +625,6 @@ def _eeg_spherepot_coil(rrs, coils, sphere):
 
 def _magnetic_dipole_field_vec(rrs, coils):
     """Compute an MEG forward solution for a set of magnetic dipoles."""
-    fwd = np.empty((3 * len(rrs), len(coils)))
     # The code below is a more efficient version (~30x) of this:
     # for ri, rr in enumerate(rrs):
     #     for k in range(len(coils)):
@@ -641,13 +641,11 @@ def _magnetic_dipole_field_vec(rrs, coils):
     #                 dist2 * this_coil['cosmag']) / dist5
     #         fwd[3*ri:3*ri+3, k] = 1e-7 * np.dot(this_coil['w'], sum_)
     if isinstance(coils, tuple):
-        rmags, cosmags, ws, n_int = coils
+        rmags, cosmags, ws, bins = coils
     else:
-        rmags, cosmags, ws, n_int = _concatenate_coils(coils)
+        rmags, cosmags, ws, bins = _concatenate_coils(coils)
     del coils
-
-    fwd = np.empty((3 * len(rrs), len(n_int)))
-    bins = np.repeat(np.arange(len(n_int)), n_int)
+    fwd = np.empty((3 * len(rrs), bins[-1] + 1))
     for ri, rr in enumerate(rrs):
         diff = rmags - rr
         dist2 = np.sum(diff * diff, axis=1)[:, np.newaxis]
@@ -658,8 +656,7 @@ def _magnetic_dipole_field_vec(rrs, coils):
                                                       axis=1)[:, np.newaxis] -
                                     dist2 * cosmags) / (dist2 * dist2 * dist)
         for ii in range(3):
-            fwd[3 * ri + ii] = np.bincount(bins, weights=sum_[:, ii],
-                                           minlength=len(n_int))
+            fwd[3 * ri + ii] = np.bincount(bins, sum_[:, ii], bins[-1] + 1)
     fwd *= 1e-7
     return fwd
 
