@@ -1,4 +1,5 @@
 # Author: Alexandre Gramfort <alexandre.gramfort@telecom-paristech.fr>
+#         Daniel Strohmeier <daniel.strohmeier@gmail.com>
 #
 # License: Simplified BSD
 
@@ -8,56 +9,128 @@ from scipy import linalg, signal
 
 from ..source_estimate import SourceEstimate
 from ..minimum_norm.inverse import combine_xyz, _prepare_forward
+from ..minimum_norm.inverse import _check_reference
 from ..forward import compute_orient_prior, is_fixed_orient, _to_fixed_ori
 from ..io.pick import pick_channels_evoked
-from .mxne_optim import mixed_norm_solver, norm_l2inf, tf_mixed_norm_solver
+from ..io.proj import deactivate_proj
 from ..utils import logger, verbose
+from ..externals.six.moves import xrange as range
+
+from .mxne_optim import (mixed_norm_solver, iterative_mixed_norm_solver,
+                         norm_l2inf, tf_mixed_norm_solver)
 
 
 @verbose
-def _prepare_gain(gain, forward, whitener, depth, loose, weights, weights_min,
-                  verbose=None):
+def _prepare_weights(forward, gain, source_weighting, weights, weights_min):
+    mask = None
+    if isinstance(weights, SourceEstimate):
+        # weights = np.sqrt(np.sum(weights.data ** 2, axis=1))
+        weights = np.max(np.abs(weights.data), axis=1)
+    weights_max = np.max(weights)
+    if weights_min > weights_max:
+        raise ValueError('weights_min > weights_max (%s > %s)' %
+                         (weights_min, weights_max))
+    weights_min = weights_min / weights_max
+    weights = weights / weights_max
+    n_dip_per_pos = 1 if is_fixed_orient(forward) else 3
+    weights = np.ravel(np.tile(weights, [n_dip_per_pos, 1]).T)
+    if len(weights) != gain.shape[1]:
+        raise ValueError('weights do not have the correct dimension '
+                         ' (%d != %d)' % (len(weights), gain.shape[1]))
+    if len(source_weighting.shape) == 1:
+        source_weighting *= weights
+    else:
+        source_weighting *= weights[:, None]
+    gain *= weights[None, :]
+
+    if weights_min is not None:
+        mask = (weights > weights_min)
+        gain = gain[:, mask]
+        n_sources = np.sum(mask) // n_dip_per_pos
+        logger.info("Reducing source space to %d sources" % n_sources)
+
+    return gain, source_weighting, mask
+
+
+@verbose
+def _prepare_gain_column(forward, info, noise_cov, pca, depth, loose, weights,
+                         weights_min, verbose=None):
+    gain_info, gain, _, whitener, _ = _prepare_forward(forward, info,
+                                                       noise_cov, pca)
+
     logger.info('Whitening lead field matrix.')
     gain = np.dot(whitener, gain)
 
-    # Handle depth prior scaling
-    source_weighting = np.sum(gain ** 2, axis=0) ** depth
+    if depth is not None:
+        depth_prior = np.sum(gain ** 2, axis=0) ** depth
+        source_weighting = np.sqrt(depth_prior ** -1.)
+    else:
+        source_weighting = np.ones(gain.shape[1], dtype=gain.dtype)
 
-    # apply loose orientations
-    orient_prior = compute_orient_prior(forward, loose)
+    if loose is not None and loose != 1.0:
+        source_weighting *= np.sqrt(compute_orient_prior(forward, loose))
 
-    source_weighting /= orient_prior
-    source_weighting = np.sqrt(source_weighting)
-    gain /= source_weighting[None, :]
+    gain *= source_weighting[None, :]
 
-    # Handle weights
-    mask = None
-    if weights is not None:
-        if isinstance(weights, SourceEstimate):
-            # weights = np.sqrt(np.sum(weights.data ** 2, axis=1))
-            weights = np.max(np.abs(weights.data), axis=1)
-        weights_max = np.max(weights)
-        if weights_min > weights_max:
-            raise ValueError('weights_min > weights_max (%s > %s)' %
-                             (weights_min, weights_max))
-        weights_min = weights_min / weights_max
-        weights = weights / weights_max
-        n_dip_per_pos = 1 if is_fixed_orient(forward) else 3
-        weights = np.ravel(np.tile(weights, [n_dip_per_pos, 1]).T)
-        if len(weights) != gain.shape[1]:
-            raise ValueError('weights do not have the correct dimension '
-                             ' (%d != %d)' % (len(weights), gain.shape[1]))
-        nz_idx = np.where(weights != 0.0)[0]
-        source_weighting[nz_idx] /= weights[nz_idx]
-        gain *= weights[None, :]
+    if weights is None:
+        mask = None
+    else:
+        gain, source_weighting, mask = _prepare_weights(forward, gain,
+                                                        source_weighting,
+                                                        weights, weights_min)
 
-        if weights_min is not None:
-            mask = (weights > weights_min)
-            gain = gain[:, mask]
-            n_sources = np.sum(mask) / n_dip_per_pos
-            logger.info("Reducing source space to %d sources" % n_sources)
+    return gain, gain_info, whitener, source_weighting, mask
 
-    return gain, source_weighting, mask
+
+def _prepare_gain(forward, info, noise_cov, pca, depth, loose, weights,
+                  weights_min, verbose=None):
+    if not isinstance(depth, float):
+        raise ValueError('Invalid depth parameter. '
+                         'A float is required (got %s).'
+                         % type(depth))
+    elif depth < 0.0:
+        raise ValueError('Depth parameter must be positive (got %s).'
+                         % depth)
+
+    gain, gain_info, whitener, source_weighting, mask = \
+        _prepare_gain_column(forward, info, noise_cov, pca, depth,
+                             loose, weights, weights_min)
+
+    return gain, gain_info, whitener, source_weighting, mask
+
+
+def _reapply_source_weighting(X, source_weighting, active_set,
+                              n_dip_per_pos):
+    X *= source_weighting[active_set][:, None]
+    return X
+
+
+def _compute_residual(forward, evoked, X, active_set, info):
+    # OK, picking based on row_names is safe
+    sel = [forward['sol']['row_names'].index(c) for c in info['ch_names']]
+    residual = evoked.copy()
+    residual = pick_channels_evoked(residual, include=info['ch_names'])
+    r_tmp = residual.copy()
+
+    r_tmp.data = np.dot(forward['sol']['data'][sel, :][:, active_set], X)
+
+    # Take care of proj
+    active_projs = list()
+    non_active_projs = list()
+    for p in evoked.info['projs']:
+        if p['active']:
+            active_projs.append(p)
+        else:
+            non_active_projs.append(p)
+
+    if len(active_projs) > 0:
+        r_tmp.info['projs'] = deactivate_proj(active_projs, copy=True)
+        r_tmp.apply_proj()
+        r_tmp.add_proj(non_active_projs, remove_existing=False)
+
+    residual.data -= r_tmp.data
+
+    return residual
 
 
 @verbose
@@ -80,8 +153,8 @@ def _make_sparse_stc(X, active_set, forward, tmin, tstep,
 
     n_lh_points = len(src[0]['vertno'])
     lh_vertno = src[0]['vertno'][active_idx[active_idx < n_lh_points]]
-    rh_vertno = src[1]['vertno'][active_idx[active_idx >= n_lh_points]
-                                             - n_lh_points]
+    rh_vertno = src[1]['vertno'][active_idx[active_idx >= n_lh_points] -
+                                 n_lh_points]
     vertices = [lh_vertno, rh_vertno]
     stc = SourceEstimate(X, vertices=vertices, tmin=tmin, tstep=tstep)
     return stc
@@ -91,17 +164,24 @@ def _make_sparse_stc(X, active_set, forward, tmin, tstep,
 def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
                maxit=3000, tol=1e-4, active_set_size=10, pca=True,
                debias=True, time_pca=True, weights=None, weights_min=None,
-               solver='auto', return_residual=False, verbose=None):
-    """Mixed-norm estimate (MxNE)
+               solver='auto', n_mxne_iter=1, return_residual=False,
+               verbose=None):
+    """Mixed-norm estimate (MxNE) and iterative reweighted MxNE (irMxNE)
 
-    Compute L1/L2 mixed-norm solution on evoked data.
+    Compute L1/L2 mixed-norm solution or L0.5/L2 mixed-norm solution
+    on evoked data.
 
     References:
-    Gramfort A., Kowalski M. and Hamalainen, M,
+    Gramfort A., Kowalski M. and Hamalainen, M.,
     Mixed-norm estimates for the M/EEG inverse problem using accelerated
     gradient methods, Physics in Medicine and Biology, 2012
     http://dx.doi.org/10.1088/0031-9155/57/7/1937
 
+    Strohmeier D., Haueisen J., and Gramfort A.,
+    Improved MEG/EEG source localization with reweighted mixed-norms,
+    4th International Workshop on Pattern Recognition in Neuroimaging,
+    Tuebingen, 2014
+
     Parameters
     ----------
     evoked : instance of Evoked or list of instances of Evoked
@@ -139,14 +219,18 @@ def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
     weights_min : float
         Do not consider in the estimation sources for which weights
         is less than weights_min.
-    solver : 'prox' | 'cd' | 'auto'
-        The algorithm to use for the optimization. prox stands for
-        proximal interations using the FISTA algorithm while cd uses
-        coordinate descent. cd is only available for fixed orientation.
-    verbose : bool, str, int, or None
-        If not None, override default verbose level (see mne.verbose).
+    solver : 'prox' | 'cd' | 'bcd' | 'auto'
+        The algorithm to use for the optimization. 'prox' stands for
+        proximal interations using the FISTA algorithm, 'cd' uses
+        coordinate descent, and 'bcd' applies block coordinate descent.
+        'cd' is only available for fixed orientation.
+    n_mxne_iter : int
+        The number of MxNE iterations. If > 1, iterative reweighting
+        is applied.
     return_residual : bool
         If True, the residual is returned as an Evoked instance.
+    verbose : bool, str, int, or None
+        If not None, override default verbose level (see mne.verbose).
 
     Returns
     -------
@@ -155,13 +239,24 @@ def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
     residual : instance of Evoked
         The residual a.k.a. data not explained by the sources.
         Only returned if return_residual is True.
+
+    See Also
+    --------
+    tf_mixed_norm
     """
+    if n_mxne_iter < 1:
+        raise ValueError('MxNE has to be computed at least 1 time. '
+                         'Requires n_mxne_iter > 0. '
+                         'Got n_mxne_iter = %d.' % n_mxne_iter)
+
     if not isinstance(evoked, list):
         evoked = [evoked]
 
+    _check_reference(evoked[0])
+
     all_ch_names = evoked[0].ch_names
     if not all(all_ch_names == evoked[i].ch_names
-                                            for i in range(1, len(evoked))):
+               for i in range(1, len(evoked))):
         raise Exception('All the datasets must have the same good channels.')
 
     # put the forward solution in fixed orientation if it's not already
@@ -169,14 +264,9 @@ def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
         forward = deepcopy(forward)
         _to_fixed_ori(forward)
 
-    info = evoked[0].info
-    gain_info, gain, _, whitener, _ = _prepare_forward(forward, info,
-                                                       noise_cov, pca)
-
-    # Whiten lead field.
-    gain, source_weighting, mask = _prepare_gain(gain, forward, whitener,
-                                                 depth, loose, weights,
-                                                 weights_min)
+    gain, gain_info, whitener, source_weighting, mask = _prepare_gain(
+        forward, evoked[0].info, noise_cov, pca, depth, loose, weights,
+        weights_min)
 
     sel = [all_ch_names.index(name) for name in gain_info['ch_names']]
     M = np.concatenate([e.data[sel] for e in evoked], axis=1)
@@ -198,14 +288,18 @@ def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
     alpha_max = norm_l2inf(np.dot(gain.T, M), n_dip_per_pos, copy=False)
     alpha_max *= 0.01
     gain /= alpha_max
-    source_weighting *= alpha_max
+    source_weighting /= alpha_max
 
-    X, active_set, E = mixed_norm_solver(M, gain, alpha,
-                                         maxit=maxit, tol=tol,
-                                         active_set_size=active_set_size,
-                                         debias=debias,
-                                         n_orient=n_dip_per_pos,
-                                         solver=solver)
+    if n_mxne_iter == 1:
+        X, active_set, E = mixed_norm_solver(
+            M, gain, alpha, maxit=maxit, tol=tol,
+            active_set_size=active_set_size, n_orient=n_dip_per_pos,
+            debias=debias, solver=solver, verbose=verbose)
+    else:
+        X, active_set, E = iterative_mixed_norm_solver(
+            M, gain, alpha, n_mxne_iter, maxit=maxit, tol=tol,
+            n_orient=n_dip_per_pos, active_set_size=active_set_size,
+            debias=debias, solver=solver, verbose=verbose)
 
     if mask is not None:
         active_set_tmp = np.zeros(len(mask), dtype=np.bool)
@@ -220,7 +314,8 @@ def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
         raise Exception("No active dipoles found. alpha is too big.")
 
     # Reapply weights to have correct unit
-    X /= source_weighting[active_set][:, None]
+    X = _reapply_source_weighting(X, source_weighting,
+                                  active_set, n_dip_per_pos)
 
     stcs = list()
     residual = list()
@@ -234,12 +329,8 @@ def mixed_norm(evoked, forward, noise_cov, alpha, loose=0.2, depth=0.8,
         cnt += len(e.times)
 
         if return_residual:
-            sel = [forward['sol']['row_names'].index(c)
-                                                for c in gain_info['ch_names']]
-            r = deepcopy(e)
-            r = pick_channels_evoked(r, include=gain_info['ch_names'])
-            r.data -= np.dot(forward['sol']['data'][sel, :][:, active_set], Xe)
-            residual.append(r)
+            residual.append(_compute_residual(forward, e, Xe, active_set,
+                            gain_info))
 
     logger.info('[done]')
 
@@ -262,7 +353,7 @@ def _window_evoked(evoked, size):
         lsize = rsize = float(size)
     else:
         lsize, rsize = size
-    evoked = deepcopy(evoked)
+    evoked = evoked.copy()
     sfreq = float(evoked.info['sfreq'])
     lsize = int(lsize * sfreq)
     rsize = int(rsize * sfreq)
@@ -279,8 +370,8 @@ def _window_evoked(evoked, size):
 def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
                   loose=0.2, depth=0.8, maxit=3000, tol=1e-4,
                   weights=None, weights_min=None, pca=True, debias=True,
-                  wsize=64, tstep=4, window=0.02,
-                  return_residual=False, verbose=None):
+                  wsize=64, tstep=4, window=0.02, return_residual=False,
+                  verbose=None):
     """Time-Frequency Mixed-norm estimate (TF-MxNE)
 
     Compute L1/L2 + L1 mixed-norm solution on time frequency
@@ -310,10 +401,10 @@ def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
         Forward operator.
     noise_cov : instance of Covariance
         Noise covariance to compute whitener.
-    alpha_space : float
+    alpha_space : float in [0, 100]
         Regularization parameter for spatial sparsity. If larger than 100,
         then no source will be active.
-    alpha_time : float
+    alpha_time : float in [0, 100]
         Regularization parameter for temporal sparsity. It set to 0,
         no temporal regularization is applied. It this case, TF-MxNE is
         equivalent to MxNE with L21 norm.
@@ -337,6 +428,8 @@ def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
         is less than weights_min.
     pca: bool
         If True the rank of the data is reduced to true dimension.
+    debias: bool
+        Remove coefficient amplitude bias due to L1 penalty.
     wsize: int
         Length of the STFT window in samples (must be a multiple of 4).
     tstep: int
@@ -346,12 +439,10 @@ def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
         Length of time window used to take care of edge artifacts in seconds.
         It can be one float or float if the values are different for left
         and right window length.
-    debias: bool
-        Remove coefficient amplitude bias due to L1 penalty.
     return_residual : bool
         If True, the residual is returned as an Evoked instance.
-    verbose: bool
-        Verbose output or not.
+    verbose : bool, str, int, or None
+        If not None, override default verbose level (see mne.verbose).
 
     Returns
     -------
@@ -360,21 +451,34 @@ def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
     residual : instance of Evoked
         The residual a.k.a. data not explained by the sources.
         Only returned if return_residual is True.
+
+    See Also
+    --------
+    mixed_norm
     """
+    _check_reference(evoked)
+
     all_ch_names = evoked.ch_names
     info = evoked.info
 
+    if (alpha_space < 0.) or (alpha_space > 100.):
+        raise Exception('alpha_space must be in range [0, 100].'
+                        ' Got alpha_space = %f' % alpha_space)
+
+    if (alpha_time < 0.) or (alpha_time > 100.):
+        raise Exception('alpha_time must be in range [0, 100].'
+                        ' Got alpha_time = %f' % alpha_time)
+
     # put the forward solution in fixed orientation if it's not already
     if loose is None and not is_fixed_orient(forward):
         forward = deepcopy(forward)
         _to_fixed_ori(forward)
 
-    gain_info, gain, _, whitener, _ = _prepare_forward(forward,
-                                                      info, noise_cov, pca)
+    n_dip_per_pos = 1 if is_fixed_orient(forward) else 3
 
-    # Whiten lead field.
-    gain, source_weighting, mask = _prepare_gain(gain, forward, whitener,
-                                        depth, loose, weights, weights_min)
+    gain, gain_info, whitener, source_weighting, mask = _prepare_gain(
+        forward, evoked.info, noise_cov, pca, depth, loose, weights,
+        weights_min)
 
     if window is not None:
         evoked = _window_evoked(evoked, window)
@@ -387,22 +491,19 @@ def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
     M = np.dot(whitener, M)
 
     # Scaling to make setting of alpha easy
-    n_dip_per_pos = 1 if is_fixed_orient(forward) else 3
     alpha_max = norm_l2inf(np.dot(gain.T, M), n_dip_per_pos, copy=False)
     alpha_max *= 0.01
     gain /= alpha_max
-    source_weighting *= alpha_max
+    source_weighting /= alpha_max
 
-    X, active_set, E = tf_mixed_norm_solver(M, gain,
-                                            alpha_space, alpha_time,
-                                            wsize=wsize, tstep=tstep,
-                                            maxit=maxit, tol=tol,
-                                            verbose=verbose,
-                                            n_orient=n_dip_per_pos,
-                                            debias=debias)
+    X, active_set, E = tf_mixed_norm_solver(
+        M, gain, alpha_space, alpha_time, wsize=wsize, tstep=tstep,
+        maxit=maxit, tol=tol, verbose=verbose, n_orient=n_dip_per_pos,
+        log_objective=False, debias=debias)
 
     if active_set.sum() == 0:
-        raise Exception("No active dipoles found. alpha is too big.")
+        raise Exception("No active dipoles found. "
+                        "alpha_space/alpha_time are too big.")
 
     if mask is not None:
         active_set_tmp = np.zeros(len(mask), dtype=np.bool)
@@ -410,23 +511,21 @@ def tf_mixed_norm(evoked, forward, noise_cov, alpha_space, alpha_time,
         active_set = active_set_tmp
         del active_set_tmp
 
-    # Reapply weights to have correct unit
-    X /= source_weighting[active_set][:, None]
+    X = _reapply_source_weighting(
+        X, source_weighting, active_set, n_dip_per_pos)
 
     if return_residual:
-        sel = [forward['sol']['row_names'].index(c)
-                                            for c in gain_info['ch_names']]
-        residual = deepcopy(evoked)
-        residual = pick_channels_evoked(residual, include=gain_info['ch_names'])
-        residual.data -= np.dot(forward['sol']['data'][sel, :][:, active_set],
-                                X)
+        residual = _compute_residual(
+            forward, evoked, X, active_set, gain_info)
+
+    stc = _make_sparse_stc(
+        X, active_set, forward, evoked.times[0], 1.0 / info['sfreq'])
 
-    tmin = evoked.times[0]
-    tstep = 1.0 / info['sfreq']
-    out = _make_sparse_stc(X, active_set, forward, tmin, tstep)
     logger.info('[done]')
 
     if return_residual:
-        out = out, residual
+        out = stc, residual
+    else:
+        out = stc
 
     return out
