@@ -3,12 +3,11 @@
 # License: BSD (3-clause)
 
 import numpy as np
-import os.path as op
 from nose.tools import assert_equal, assert_raises
 
 from mne import create_info
 from mne.io import RawArray
-from mne.utils import logger, set_log_file, slow_test, _TempDir
+from mne.utils import logger, catch_logging, slow_test, run_tests_if_main
 
 
 def bad_1(x):
@@ -44,15 +43,10 @@ def test_apply_function_verbose():
                   None, None, 2)
 
     # check our arguments
-    tempdir = _TempDir()
-    test_name = op.join(tempdir, 'test.log')
-    set_log_file(test_name)
-    try:
+    with catch_logging() as sio:
         raw.apply_function(printer, None, None, 1, verbose=False)
-        with open(test_name) as fid:
-            assert_equal(len(fid.readlines()), 0)
+        assert_equal(len(sio.getvalue()), 0)
         raw.apply_function(printer, None, None, 1, verbose=True)
-        with open(test_name) as fid:
-            assert_equal(len(fid.readlines()), n_chan)
-    finally:
-        set_log_file(None)
+        assert_equal(sio.getvalue().count('\n'), n_chan)
+
+run_tests_if_main()
