@@ -4,7 +4,7 @@
 
 import numpy as np
 from ..evoked import Evoked
-from ..epochs import Epochs
+from ..epochs import _BaseEpochs
 from ..io import Raw
 from ..event import find_events
 
@@ -106,7 +106,7 @@ def fix_stim_artifact(inst, events=None, event_id=None, tmin=0.,
             last_samp = int(event_idx) - inst.first_samp + s_end
             _fix_artifact(data, window, picks, first_samp, last_samp, mode)
 
-    elif isinstance(inst, Epochs):
+    elif isinstance(inst, _BaseEpochs):
         _check_preload(inst)
         if inst.reject is not None:
             raise RuntimeError('Reject is already applied. Use reject=None '
