@@ -1,13 +1,13 @@
 import os.path as op
 from nose.tools import assert_true
 
-from mne.fiff import Raw
+from mne.io import Raw
 from mne.preprocessing.eog import find_eog_events
 
-data_path = op.join(op.dirname(__file__), '..', '..', 'fiff', 'tests', 'data')
+data_path = op.join(op.dirname(__file__), '..', '..', 'io', 'tests', 'data')
 raw_fname = op.join(data_path, 'test_raw.fif')
 event_fname = op.join(data_path, 'test-eve.fif')
-proj_fname = op.join(data_path, 'test_proj.fif')
+proj_fname = op.join(data_path, 'test-proj.fif')
 
 
 def test_find_eog():
