@@ -1,7 +1,6 @@
 """Functions for statistical analysis"""
 
-from .parametric import (
-    f_threshold_twoway_rm, f_threshold_mway_rm, f_twoway_rm, f_mway_rm)
+from .parametric import f_threshold_mway_rm, f_mway_rm
 from .permutations import permutation_t_test
 from .cluster_level import (permutation_cluster_test,
                             permutation_cluster_1samp_test,
