@@ -1,5 +1,4 @@
 import os
-import os.path as op
 import numpy as np
 from numpy.testing import (assert_equal, assert_array_equal,
                            assert_array_almost_equal)
@@ -13,7 +12,7 @@ from mne.stats.cluster_level import (permutation_cluster_test,
                                      spatio_temporal_cluster_test,
                                      spatio_temporal_cluster_1samp_test,
                                      ttest_1samp_no_p, summarize_clusters_stc)
-from mne.utils import run_tests_if_main, slow_test, _TempDir, set_log_file
+from mne.utils import run_tests_if_main, slow_test, _TempDir, catch_logging
 
 warnings.simplefilter('always')  # enable b/c these tests throw warnings
 
@@ -52,22 +51,21 @@ def test_cache_dir():
     orig_size = os.getenv('MNE_MEMMAP_MIN_SIZE', None)
     rng = np.random.RandomState(0)
     X = rng.randn(9, 2, 10)
-    log_file = op.join(tempdir, 'log.txt')
     try:
         os.environ['MNE_MEMMAP_MIN_SIZE'] = '1K'
         os.environ['MNE_CACHE_DIR'] = tempdir
         # Fix error for #1507: in-place when memmapping
-        permutation_cluster_1samp_test(
-            X, buffer_size=None, n_jobs=2, n_permutations=1,
-            seed=0, stat_fun=ttest_1samp_no_p, verbose=False)
-        # ensure that non-independence yields warning
-        stat_fun = partial(ttest_1samp_no_p, sigma=1e-3)
-        set_log_file(log_file)
-        permutation_cluster_1samp_test(
-            X, buffer_size=10, n_jobs=2, n_permutations=1,
-            seed=0, stat_fun=stat_fun, verbose=False)
-        with open(log_file, 'r') as fid:
-            assert_true('independently' in ''.join(fid.readlines()))
+        with catch_logging() as log_file:
+            permutation_cluster_1samp_test(
+                X, buffer_size=None, n_jobs=2, n_permutations=1,
+                seed=0, stat_fun=ttest_1samp_no_p, verbose=False)
+            # ensure that non-independence yields warning
+            stat_fun = partial(ttest_1samp_no_p, sigma=1e-3)
+            assert_true('independently' not in log_file.getvalue())
+            permutation_cluster_1samp_test(
+                X, buffer_size=10, n_jobs=2, n_permutations=1,
+                seed=0, stat_fun=stat_fun, verbose=False)
+            assert_true('independently' in log_file.getvalue())
     finally:
         if orig_dir is not None:
             os.environ['MNE_CACHE_DIR'] = orig_dir
@@ -77,7 +75,6 @@ def test_cache_dir():
             os.environ['MNE_MEMMAP_MIN_SIZE'] = orig_size
         else:
             del os.environ['MNE_MEMMAP_MIN_SIZE']
-        set_log_file(None)
 
 
 def test_permutation_step_down_p():
