@@ -16,13 +16,12 @@ from numpy.testing import (assert_array_almost_equal, assert_equal,
 from nose.tools import assert_true, assert_raises, assert_not_equal
 
 from mne import (equalize_channels, pick_types, read_evokeds, write_evokeds,
-                 grand_average, combine_evoked)
-from mne.evoked import _get_peak, EvokedArray
+                 grand_average, combine_evoked, create_info)
+from mne.evoked import _get_peak, Evoked, EvokedArray
 from mne.epochs import EpochsArray
 
 from mne.utils import _TempDir, requires_pandas, slow_test, requires_version
 
-from mne.io.meas_info import create_info
 from mne.externals.six.moves import cPickle as pickle
 
 warnings.simplefilter('always')
@@ -101,10 +100,9 @@ def test_io_evoked():
     assert_array_almost_equal(ave.data, ave3.data, 19)
 
     # test read_evokeds and write_evokeds
-    types = ['Left Auditory', 'Right Auditory', 'Left visual', 'Right visual']
-    aves1 = read_evokeds(fname)
-    aves2 = read_evokeds(fname, [0, 1, 2, 3])
-    aves3 = read_evokeds(fname, types)
+    aves1 = read_evokeds(fname)[1::2]
+    aves2 = read_evokeds(fname, [1, 3])
+    aves3 = read_evokeds(fname, ['Right Auditory', 'Right visual'])
     write_evokeds(op.join(tempdir, 'evoked-ave.fif'), aves1)
     aves4 = read_evokeds(op.join(tempdir, 'evoked-ave.fif'))
     for aves in [aves2, aves3, aves4]:
@@ -126,6 +124,9 @@ def test_io_evoked():
         read_evokeds(fname2)
     assert_true(len(w) == 2)
 
+    # constructor
+    assert_raises(TypeError, Evoked, fname)
+
 
 def test_shift_time_evoked():
     """ Test for shifting of time scale
@@ -266,13 +267,14 @@ def test_get_peak():
     assert_raises(RuntimeError, evoked.get_peak, ch_type=None, mode='foo')
     assert_raises(ValueError, evoked.get_peak, ch_type='misc', mode='foo')
 
-    ch_idx, time_idx = evoked.get_peak(ch_type='mag')
-    assert_true(ch_idx in evoked.ch_names)
+    ch_name, time_idx = evoked.get_peak(ch_type='mag')
+    assert_true(ch_name in evoked.ch_names)
     assert_true(time_idx in evoked.times)
 
-    ch_idx, time_idx = evoked.get_peak(ch_type='mag',
-                                       time_as_index=True)
+    ch_name, time_idx = evoked.get_peak(ch_type='mag',
+                                        time_as_index=True)
     assert_true(time_idx < len(evoked.times))
+    assert_equal(ch_name, 'MEG 1421')
 
     data = np.array([[0., 1.,  2.],
                      [0., -3.,  0]])
