@@ -14,7 +14,7 @@ from .io.constants import FIFF
 from .io.open import fiff_open
 from .io.tag import read_tag
 from .io.write import start_file, end_file, write_coord_trans
-from .utils import check_fname, logger, deprecated
+from .utils import check_fname, logger
 from .externals.six import string_types
 
 
@@ -318,32 +318,33 @@ def _ensure_trans(trans, fro='mri', to='head'):
     return trans
 
 
-def _get_mri_head_t(trans):
+def _get_trans(trans, fro='mri', to='head'):
     """Get mri_head_t (from=mri, to=head) from mri filename"""
     if isinstance(trans, string_types):
         if not op.isfile(trans):
             raise IOError('trans file "%s" not found' % trans)
         if op.splitext(trans)[1] in ['.fif', '.gz']:
-            mri_head_t = read_trans(trans)
+            fro_to_t = read_trans(trans)
         else:
             # convert "-trans.txt" to "-trans.fif" mri-type equivalent
+            # these are usually actually in to_fro form
             t = np.genfromtxt(trans)
             if t.ndim != 2 or t.shape != (4, 4):
                 raise RuntimeError('File "%s" did not have 4x4 entries'
                                    % trans)
-            mri_head_t = Transform('head', 'mri', t)
+            fro_to_t = Transform(to, fro, t)
     elif isinstance(trans, dict):
-        mri_head_t = trans
+        fro_to_t = trans
         trans = 'dict'
     elif trans is None:
-        mri_head_t = Transform('head', 'mri', np.eye(4))
+        fro_to_t = Transform(fro, to, np.eye(4))
         trans = 'identity'
     else:
-        raise ValueError('trans type %s not known, must be str, dict, or None'
-                         % type(trans))
+        raise ValueError('transform type %s not known, must be str, dict, '
+                         'or None' % type(trans))
     # it's usually a head->MRI transform, so we probably need to invert it
-    mri_head_t = _ensure_trans(mri_head_t, 'mri', 'head')
-    return mri_head_t, trans
+    fro_to_t = _ensure_trans(fro_to_t, fro, to)
+    return fro_to_t, trans
 
 
 def combine_transforms(t_first, t_second, fro, to):
@@ -487,113 +488,6 @@ def transform_surface_to(surf, dest, trans):
     return surf
 
 
-@deprecated('transform_coordinates is deprecated and will be removed in v0.11')
-def transform_coordinates(filename, pos, orig, dest):
-    """Transform coordinates between various MRI-related coordinate frames
-
-    Parameters
-    ----------
-    filename: string
-        Name of a fif file containing the coordinate transformations
-        This file can be conveniently created with mne_collect_transforms
-        or ``collect_transforms``.
-    pos: array of shape N x 3
-        array of locations to transform (in meters)
-    orig: 'meg' | 'mri'
-        Coordinate frame of the above locations.
-        'meg' is MEG head coordinates
-        'mri' surface RAS coordinates
-    dest: 'meg' | 'mri' | 'fs_tal' | 'mni_tal'
-        Coordinate frame of the result.
-        'mni_tal' is MNI Talairach
-        'fs_tal' is FreeSurfer Talairach
-
-    Returns
-    -------
-    trans_pos: array of shape N x 3
-        The transformed locations
-
-    Examples
-    --------
-    transform_coordinates('all-trans.fif', np.eye(3), 'meg', 'fs_tal')
-    transform_coordinates('all-trans.fif', np.eye(3), 'mri', 'mni_tal')
-    """
-    #   Read the fif file containing all necessary transformations
-    fid, tree, directory = fiff_open(filename)
-
-    coord_names = dict(mri=FIFF.FIFFV_COORD_MRI,
-                       meg=FIFF.FIFFV_COORD_HEAD,
-                       mni_tal=FIFF.FIFFV_MNE_COORD_MNI_TAL,
-                       fs_tal=FIFF.FIFFV_MNE_COORD_FS_TAL)
-
-    orig = coord_names[orig]
-    dest = coord_names[dest]
-
-    T0 = T1 = T2 = T3plus = T3minus = None
-    for d in directory:
-        if d.kind == FIFF.FIFF_COORD_TRANS:
-            tag = read_tag(fid, d.pos)
-            trans = tag.data
-            if (trans['from'] == FIFF.FIFFV_COORD_MRI and
-                    trans['to'] == FIFF.FIFFV_COORD_HEAD):
-                T0 = invert_transform(trans)
-            elif (trans['from'] == FIFF.FIFFV_COORD_MRI and
-                  trans['to'] == FIFF.FIFFV_MNE_COORD_RAS):
-                T1 = trans
-            elif (trans['from'] == FIFF.FIFFV_MNE_COORD_RAS and
-                  trans['to'] == FIFF.FIFFV_MNE_COORD_MNI_TAL):
-                T2 = trans
-            elif trans['from'] == FIFF.FIFFV_MNE_COORD_MNI_TAL:
-                if trans['to'] == FIFF.FIFFV_MNE_COORD_FS_TAL_GTZ:
-                    T3plus = trans
-                elif trans['to'] == FIFF.FIFFV_MNE_COORD_FS_TAL_LTZ:
-                    T3minus = trans
-    fid.close()
-    #
-    #   Check we have everything we need
-    #
-    if ((orig == FIFF.FIFFV_COORD_HEAD and T0 is None) or (T1 is None) or
-            (T2 is None) or (dest == FIFF.FIFFV_MNE_COORD_FS_TAL and
-                             ((T3minus is None) or (T3minus is None)))):
-        raise ValueError('All required coordinate transforms not found')
-
-    #
-    #   Go ahead and transform the data
-    #
-    if pos.shape[1] != 3:
-        raise ValueError('Coordinates must be given in a N x 3 array')
-
-    if dest == orig:
-        trans_pos = pos.copy()
-    else:
-        n_points = pos.shape[0]
-        pos = np.c_[pos, np.ones(n_points)].T
-        if orig == FIFF.FIFFV_COORD_HEAD:
-            pos = np.dot(T0['trans'], pos)
-        elif orig != FIFF.FIFFV_COORD_MRI:
-            raise ValueError('Input data must be in MEG head or surface RAS '
-                             'coordinates')
-
-        if dest == FIFF.FIFFV_COORD_HEAD:
-            pos = np.dot(linalg.inv(T0['trans']), pos)
-        elif dest != FIFF.FIFFV_COORD_MRI:
-            pos = np.dot(np.dot(T2['trans'], T1['trans']), pos)
-            if dest != FIFF.FIFFV_MNE_COORD_MNI_TAL:
-                if dest == FIFF.FIFFV_MNE_COORD_FS_TAL:
-                    for k in range(n_points):
-                        if pos[2, k] > 0:
-                            pos[:, k] = np.dot(T3plus['trans'], pos[:, k])
-                        else:
-                            pos[:, k] = np.dot(T3minus['trans'], pos[:, k])
-                else:
-                    raise ValueError('Illegal choice for the output '
-                                     'coordinates')
-
-        trans_pos = pos[:3, :].T
-
-    return trans_pos
-
-
 def get_ras_to_neuromag_trans(nasion, lpa, rpa):
     """Construct a transformation matrix to the MNE head coordinate system
 
@@ -646,24 +540,6 @@ def get_ras_to_neuromag_trans(nasion, lpa, rpa):
     return trans
 
 
-@deprecated('collect_transforms is deprecated and will be removed in v0.11')
-def collect_transforms(fname, xforms):
-    """Collect a set of transforms in a single FIFF file
-
-    Parameters
-    ----------
-    fname : str
-        Filename to save to.
-    xforms : list of dict
-        List of transformations.
-    """
-    check_fname(fname, 'trans', ('-trans.fif', '-trans.fif.gz'))
-    with start_file(fname) as fid:
-        for xform in xforms:
-            write_coord_trans(fid, xform)
-        end_file(fid)
-
-
 def _sphere_to_cartesian(theta, phi, r):
     """Transform spherical coordinates to cartesian"""
     z = r * np.sin(phi)
@@ -687,3 +563,10 @@ def _cartesian_to_sphere(x, y, z):
     elev = np.arctan2(z, hypotxy)
     az = np.arctan2(y, x)
     return az, elev, r
+
+
+def _topo_to_sphere(theta, radius):
+    """Convert 2D topo coordinates to spherical."""
+    sph_phi = (0.5 - radius) * 180
+    sph_theta = -theta
+    return sph_phi, sph_theta
