@@ -14,6 +14,7 @@ from functools import partial
 
 import numpy as np
 
+from .utils import plt_show
 from ..externals.six import string_types
 from ..fixes import tril_indices, normalize_colors
 
@@ -409,6 +410,5 @@ def plot_connectivity_circle(con, node_names, indices=None, n_lines=None,
 
         fig.canvas.mpl_connect('button_press_event', callback)
 
-    if show:
-        plt.show()
+    plt_show(show)
     return fig, axes
