@@ -17,11 +17,11 @@ import numpy as np
 
 from ..io.pick import channel_type, pick_types
 from ..fixes import normalize_colors
-from ..utils import _clean_names, deprecated
+from ..utils import _clean_names
 
 from ..defaults import _handle_default
 from .utils import (_check_delayed_ssp, COLORS, _draw_proj_checkbox,
-                    add_background_image)
+                    add_background_image, plt_show)
 
 
 def iter_topography(info, layout=None, on_pick=None, fig=None,
@@ -239,78 +239,6 @@ def _check_vlim(vlim):
     return not np.isscalar(vlim) and vlim is not None
 
 
-@deprecated("It will be removed in version 0.11. "
-            "Please use evoked.plot_topo or viz.evoked.plot_evoked_topo "
-            "for list of evoked instead.")
-def plot_topo(evoked, layout=None, layout_scale=0.945, color=None,
-              border='none', ylim=None, scalings=None, title=None, proj=False,
-              vline=[0.0], fig_facecolor='k', fig_background=None,
-              axis_facecolor='k', font_color='w', show=True):
-    """Plot 2D topography of evoked responses.
-
-    Clicking on the plot of an individual sensor opens a new figure showing
-    the evoked response for the selected sensor.
-
-    Parameters
-    ----------
-    evoked : list of Evoked | Evoked
-        The evoked response to plot.
-    layout : instance of Layout | None
-        Layout instance specifying sensor positions (does not need to
-        be specified for Neuromag data). If possible, the correct layout is
-        inferred from the data.
-    layout_scale: float
-        Scaling factor for adjusting the relative size of the layout
-        on the canvas
-    color : list of color objects | color object | None
-        Everything matplotlib accepts to specify colors. If not list-like,
-        the color specified will be repeated. If None, colors are
-        automatically drawn.
-    border : str
-        matplotlib borders style to be used for each sensor plot.
-    ylim : dict | None
-        ylim for plots. The value determines the upper and lower subplot
-        limits. e.g. ylim = dict(eeg=[-200e-6, 200e6]). Valid keys are eeg,
-        mag, grad, misc. If None, the ylim parameter for each channel is
-        determined by the maximum absolute peak.
-    scalings : dict | None
-        The scalings of the channel types to be applied for plotting. If None,`
-        defaults to `dict(eeg=1e6, grad=1e13, mag=1e15)`.
-    title : str
-        Title of the figure.
-    proj : bool | 'interactive'
-        If true SSP projections are applied before display. If 'interactive',
-        a check box for reversible selection of SSP projection vectors will
-        be shown.
-    vline : list of floats | None
-        The values at which to show a vertical line.
-    fig_facecolor : str | obj
-        The figure face color. Defaults to black.
-    fig_background : None | numpy ndarray
-        A background image for the figure. This must work with a call to
-        plt.imshow. Defaults to None.
-    axis_facecolor : str | obj
-        The face color to be used for each sensor plot. Defaults to black.
-    font_color : str | obj
-        The color of text in the colorbar and title. Defaults to white.
-    show : bool
-        Show figure if True.
-
-    Returns
-    -------
-    fig : Instance of matplotlib.figure.Figure
-        Images of evoked responses at sensor locations
-    """
-    return _plot_evoked_topo(evoked=evoked, layout=layout,
-                             layout_scale=layout_scale, color=color,
-                             border=border, ylim=ylim, scalings=scalings,
-                             title=title, proj=proj, vline=vline,
-                             fig_facecolor=fig_facecolor,
-                             fig_background=fig_background,
-                             axis_facecolor=axis_facecolor,
-                             font_color=font_color, show=show)
-
-
 def _plot_evoked_topo(evoked, layout=None, layout_scale=0.945, color=None,
                       border='none', ylim=None, scalings=None, title=None,
                       proj=False, vline=[0.0], fig_facecolor='k',
@@ -371,8 +299,6 @@ def _plot_evoked_topo(evoked, layout=None, layout_scale=0.945, color=None,
     fig : Instance of matplotlib.figure.Figure
         Images of evoked responses at sensor locations
     """
-    import matplotlib.pyplot as plt
-
     if not type(evoked) in (tuple, list):
         evoked = [evoked]
 
@@ -473,9 +399,7 @@ def _plot_evoked_topo(evoked, layout=None, layout_scale=0.945, color=None,
                       projs=evoked[0].info['projs'], fig=fig)
         _draw_proj_checkbox(None, params)
 
-    if show:
-        plt.show()
-
+    plt_show(show)
     return fig
 
 
@@ -595,7 +519,6 @@ def plot_topo_image_epochs(epochs, layout=None, sigma=0., vmin=None,
     fig : instance of matplotlib figure
         Figure distributing one image per channel across sensor topography.
     """
-    import matplotlib.pyplot as plt
     scalings = _handle_default('scalings', scalings)
     data = epochs.get_data()
     if vmin is None:
@@ -617,6 +540,5 @@ def plot_topo_image_epochs(epochs, layout=None, sigma=0., vmin=None,
                      fig_facecolor=fig_facecolor,
                      font_color=font_color, border=border,
                      x_label='Time (s)', y_label='Epoch')
-    if show:
-        plt.show()
+    plt_show(show)
     return fig
