@@ -21,11 +21,13 @@ from ..io.constants import FIFF
 from ..io.pick import pick_types
 from ..utils import _clean_names, _time_mask, verbose, logger
 from .utils import (tight_layout, _setup_vmin_vmax, _prepare_trellis,
-                    _check_delayed_ssp, _draw_proj_checkbox, figure_nobar)
+                    _check_delayed_ssp, _draw_proj_checkbox, figure_nobar,
+                    plt_show)
 from ..time_frequency import compute_epochs_psd
 from ..defaults import _handle_default
 from ..channels.layout import _find_topomap_coords
 from ..fixes import _get_argrelmax
+from ..externals.six import string_types
 
 
 def _prepare_topo_plot(inst, ch_type, layout):
@@ -221,7 +223,7 @@ def plot_projs_topomap(projs, layout=None, cmap='RdBu_r', sensors=True,
             pos = l.pos[idx]
             if is_vv and grad_pairs:
                 from ..channels.layout import _merge_grad_data
-                shape = (len(idx) / 2, 2, -1)
+                shape = (len(idx) // 2, 2, -1)
                 pos = pos.reshape(shape).mean(axis=1)
                 data = _merge_grad_data(data[grad_pairs]).ravel()
 
@@ -238,9 +240,7 @@ def plot_projs_topomap(projs, layout=None, cmap='RdBu_r', sensors=True,
             raise RuntimeError('Cannot find a proper layout for projection %s'
                                % proj['desc'])
     tight_layout(fig=axes[0].get_figure())
-    if show and plt.get_backend() != 'agg':
-        plt.show()
-
+    plt_show(show)
     return axes[0].get_figure()
 
 
@@ -403,6 +403,7 @@ def plot_topomap(data, pos, vmin=None, vmax=None, cmap='RdBu_r', sensors=True,
         delete the prefix 'MEG ' from all channel names, pass the function
         lambda x: x.replace('MEG ', ''). If `mask` is not None, only
         significant sensors will be shown.
+        If `True`, a list of names must be provided (see `names` keyword).
     mask : ndarray of bool, shape (n_channels, n_times) | None
         The channels to be marked as significant at a given time point.
         Indices set to `True` will be considered. Defaults to None.
@@ -486,16 +487,9 @@ def plot_topomap(data, pos, vmin=None, vmax=None, cmap='RdBu_r', sensors=True,
     vmin, vmax = _setup_vmin_vmax(data, vmin, vmax)
 
     pos, outlines = _check_outlines(pos, outlines, head_pos)
-    pos_x = pos[:, 0]
-    pos_y = pos[:, 1]
 
     ax = axis if axis else plt.gca()
-    ax.set_xticks([])
-    ax.set_yticks([])
-    ax.set_frame_on(False)
-    if any([not pos_y.any(), not pos_x.any()]):
-        raise RuntimeError('No position information found, cannot compute '
-                           'geometries for topomap.')
+    pos_x, pos_y = _prepare_topomap(pos, ax)
     if outlines is None:
         xmin, xmax = pos_x.min(), pos_x.max()
         ymin, ymax = pos_y.min(), pos_y.max()
@@ -587,6 +581,9 @@ def plot_topomap(data, pos, vmin=None, vmax=None, cmap='RdBu_r', sensors=True,
             ax.plot(x, y, color='k', linewidth=linewidth, clip_on=False)
 
     if show_names:
+        if names is None:
+            raise ValueError("To show names, a list of names must be provided"
+                             " (see `names` keyword).")
         if show_names is True:
             def _show_names(x):
                 return x
@@ -604,8 +601,7 @@ def plot_topomap(data, pos, vmin=None, vmax=None, cmap='RdBu_r', sensors=True,
 
     if onselect is not None:
         ax.RS = RectangleSelector(ax, onselect=onselect)
-    if show:
-        plt.show()
+    plt_show(show)
     return im, cont
 
 
@@ -805,9 +801,7 @@ def plot_ica_components(ica, picks=None, ch_type=None, res=64,
     tight_layout(fig=fig)
     fig.subplots_adjust(top=0.95)
     fig.canvas.draw()
-
-    if show is True:
-        plt.show()
+    plt_show(show)
     return fig
 
 
@@ -995,9 +989,7 @@ def plot_tfr_topomap(tfr, tmin=None, tmax=None, fmin=None, fmax=None,
         cbar.ax.tick_params(labelsize=12)
         cbar.ax.set_title('AU')
 
-    if show:
-        plt.show()
-
+    plt_show(show)
     return fig
 
 
@@ -1137,14 +1129,16 @@ def plot_evoked_topomap(evoked, times="auto", ch_type=None, layout=None,
     if isinstance(axes, plt.Axes):
         axes = [axes]
 
-    if times == "peaks":
-        npeaks = 10 if axes is None else len(axes)
-        times = _find_peaks(evoked, npeaks)
-    elif times == "auto":
-        if axes is None:
-            times = np.linspace(evoked.times[0], evoked.times[-1], 10)
-        else:
-            times = np.linspace(evoked.times[0], evoked.times[-1], len(axes))
+    if isinstance(times, string_types):
+        if times == "peaks":
+            npeaks = 10 if axes is None else len(axes)
+            times = _find_peaks(evoked, npeaks)
+        elif times == "auto":
+            if axes is None:
+                times = np.linspace(evoked.times[0], evoked.times[-1], 10)
+            else:
+                times = np.linspace(evoked.times[0], evoked.times[-1],
+                                    len(axes))
     elif np.isscalar(times):
         times = [times]
 
@@ -1263,7 +1257,6 @@ def plot_evoked_topomap(evoked, times="auto", ch_type=None, layout=None,
 
     if title is not None:
         plt.suptitle(title, verticalalignment='top', size='x-large')
-        tight_layout(pad=size, fig=fig)
 
     if colorbar:
         cax = plt.subplot(1, n_times + 1, n_times + 1)
@@ -1289,9 +1282,7 @@ def plot_evoked_topomap(evoked, times="auto", ch_type=None, layout=None,
                       plot_update_proj_callback=_plot_update_evoked_topomap)
         _draw_proj_checkbox(None, params)
 
-    if show:
-        plt.show()
-
+    plt_show(show)
     return fig
 
 
@@ -1532,8 +1523,7 @@ def plot_psds_topomap(
                                  colorbar=True, unit=unit, cbar_fmt=cbar_fmt)
     tight_layout(fig=fig)
     fig.canvas.draw()
-    if show:
-        plt.show()
+    plt_show(show)
     return fig
 
 
@@ -1600,7 +1590,7 @@ def _onselect(eclick, erelease, tfr, pos, ch_type, itmin, itmax, ifmin, ifmax,
         fig[0].get_axes()[1].cbar.on_mappable_changed(mappable=img)
     fig[0].canvas.draw()
     plt.figure(fig[0].number)
-    plt.show()
+    plt_show(True)
 
 
 def _find_peaks(evoked, npeaks):
@@ -1620,3 +1610,17 @@ def _find_peaks(evoked, npeaks):
     if len(times) == 0:
         times = [evoked.times[gfp.argmax()]]
     return times
+
+
+def _prepare_topomap(pos, ax):
+    """Helper for preparing the topomap."""
+    pos_x = pos[:, 0]
+    pos_y = pos[:, 1]
+
+    ax.set_xticks([])
+    ax.set_yticks([])
+    ax.set_frame_on(False)
+    if any([not pos_y.any(), not pos_x.any()]):
+        raise RuntimeError('No position information found, cannot compute '
+                           'geometries for topomap.')
+    return pos_x, pos_y
